@@ -35,6 +35,7 @@ class EgoboxEgorDriver(Driver):
             raise RuntimeError("egobox library is not installed.")
 
         # What we support
+        self.supports["optimization"] = True
         self.supports["inequality_constraints"] = True
         self.supports["linear_constraints"] = True
         self.supports["integer_design_vars"] = True
@@ -47,6 +48,7 @@ class EgoboxEgorDriver(Driver):
         self.supports["simultaneous_derivatives"] = False
         self.supports["total_jac_sparsity"] = False
         self.supports["gradients"] = False
+        self.supports._read_only = True
 
         self.opt_settings = {}
 
@@ -67,7 +69,7 @@ class EgoboxEgorDriver(Driver):
         model = self._problem().model
 
         self.iter_count = 0
-        self.name = f"onera_optimizer_{self.options['optimizer'].lower()}"
+        self.name = f"egobox_optimizer_{self.options['optimizer'].lower()}"
 
         # Initial Run
         with RecordingDebugging(self.name, self.iter_count, self) as rec:
@@ -107,7 +109,7 @@ class EgoboxEgorDriver(Driver):
         )
 
         # Run the optim
-        res = egor.minimize(n_eval=n_iter)
+        res = egor.minimize(n_iter=n_iter)
 
         # Set optimal parameters
         i = 0
@@ -132,25 +134,25 @@ class EgoboxEgorDriver(Driver):
                 if name == infos[absname]["prom_name"] and (
                     infos[absname]["tags"] & {"wop:int"}
                 ):
-                    dvs_int[name] = egx.Vtype(egx.Vtype.INT)
+                    dvs_int[name] = egx.XType(egx.XType.INT)
 
         variables = []
         desvars = self._designvars
         for name, meta in desvars.items():
-            vartype = dvs_int.get(name, egx.Vtype(egx.Vtype.FLOAT))
+            vartype = dvs_int.get(name, egx.XType(egx.XType.FLOAT))
             if meta["size"] > 1:
                 if np.isscalar(meta["lower"]):
                     variables += [
-                        egx.Vspec(vartype, [meta["lower"], meta["upper"]])
+                        egx.XSpec(vartype, [meta["lower"], meta["upper"]])
                         for i in range(meta["size"])
                     ]
                 else:
                     variables += [
-                        egx.Vspec(vartype, [meta["lower"], meta["upper"]])
+                        egx.XSpec(vartype, [meta["lower"], meta["upper"]])
                         for i in range(meta["size"])
                     ]
             else:
-                variables += [egx.Vspec(vartype, [meta["lower"], meta["upper"]])]
+                variables += [egx.XSpec(vartype, [meta["lower"], meta["upper"]])]
         return variables
 
     def _initialize_cons(self, eq_tol=None, ieq_tol=None):
